@@ -1023,8 +1023,7 @@ class EducPlanPosGroup(Base):
     """
     Группа позиции учебного плана
     """
-
-    __table__ = 'univer_educ_plan_pos_groups'
+    __tablename__ = 'univer_educ_plan_pos_groups'
 
     # Идентификатор
     id = Column('pos_group_id', Integer, primary_key=True)
